@@ -309,7 +309,7 @@ def random_hostname():
 
 
 def create_bwrap_argv(config):
-    my_home = os.path.realpath(os.path.expanduser('~'))
+    my_home = os.path.expanduser('~')
     mount_tasks = [
         MountTask(MountMode.TMPFS, '/'),
         MountTask(MountMode.BIND_RO, '/bin'),
@@ -333,6 +333,7 @@ def create_bwrap_argv(config):
 
     argv.add('bwrap')
     argv.add('--new-session')
+    argv.add('--die-with-parent')
 
     # Hostname
     hostname = random_hostname()
@@ -386,7 +387,9 @@ def create_bwrap_argv(config):
 
     # Extra binds
     for bind in config.extra_binds:
-        mount_target, mount_access = parse_path_colon_access(bind)
+        mount_target_orig, mount_access = parse_path_colon_access(bind)
+        mount_target = os.path.abspath(mount_target_orig)
+        del mount_target_orig
         if mount_access == AccessMode.READ_WRITE:
             mount_mode = MountMode.BIND_RW
         else:
@@ -396,7 +399,7 @@ def create_bwrap_argv(config):
 
     # Program
     if os.sep in (config.argv_0 or ''):
-        real_argv_0 = os.path.realpath(config.argv_0)
+        real_argv_0 = os.path.abspath(config.argv_0)
         mount_tasks += [
             MountTask(MountMode.BIND_RO, real_argv_0, required=False),
             MountTask(MountMode.BIND_RO, real_argv_0 + '.exe', required=False),
